@@ -2,7 +2,7 @@ import json
 
 from django.core import serializers as django_serializers
 from django.http import JsonResponse, HttpResponse, QueryDict
-from django.shortcuts import render
+from django.shortcuts import render, get_object_or_404
 from django.utils.decorators import method_decorator
 from django.views.decorators.csrf import ensure_csrf_cookie, csrf_exempt
 from polymorphic.models import PolymorphicTypeInvalid
@@ -360,6 +360,8 @@ class HardwareViewSet(viewsets.ModelViewSet):
                 hardware.get_real_concrete_instance_class().delete()
             return HttpResponse(render(request, 'hardwares.html'))
 
+from data.forms.forms import DataTransformerForm
+from data.models.models import DataTransformer
 
 class AccessoryViewSet(viewsets.ModelViewSet):
     queryset = Accessory.objects.all()
@@ -382,9 +384,17 @@ class AccessoryViewSet(viewsets.ModelViewSet):
         calibrations = accessory.calibration_set.all()
         accessory_form = AccessoryForm(instance=accessory)
         calibration_form = CalibrationForm(initial={'accessory': accessory})
+
+
+        data_transformer = accessory.datatransformer
+        formset = DataTransformerForm(instance=data_transformer)
+
+        if formset.is_valid():
+            formset.save()
+            return redirect('parent_view', parent_id=data_transformer.id)
         if request.accepted_renderer.format == 'html':
             return Response(
-                {"accessory_form": accessory_form, "calibration_form": calibration_form, "calibrations": calibrations},
+                {"accessory_form": accessory_form, "calibration_form": calibration_form, "calibrations": calibrations, "data_transformer_form":formset},
                 template_name='accessory.html')
         else:
             return super(AccessoryViewSet, self).retrieve()
@@ -410,6 +420,23 @@ class AccessoryViewSet(viewsets.ModelViewSet):
         # some error occured
         return JsonResponse({"error": ""}, status=400)
 
+    def postDataTransformer(request):
+        # request should be ajax and method should be POST.
+        if request.is_ajax and request.method == "POST":
+            form = DataTransformerForm(request.POST)
+            if form.is_valid():
+                instance = form.save()
+                print(str(instance))
+                # serialize in new friend object in json
+                ser_instance = django_serializers.serialize('json', [instance, ])
+                print(str(ser_instance))
+                # send to client side.
+                return JsonResponse({"instance": ser_instance}, status=200)
+            else:
+                # some form errors occured.
+                return JsonResponse({"error": form.errors}, status=400)
+        return JsonResponse({"error": ""}, status=400)
+
     def postCalibration(request):
         print('post calibration')
 
@@ -824,3 +851,5 @@ def listHubAccessories(request, hub_id):
     serialized_accessories = AccessorySerializer(many=True).to_representation(accessories)
 
     return JsonResponse(serialized_accessories, status=200, safe=False)
+
+
